@@ -1,7 +1,7 @@
-/* $Id: exo-md5.c 61 2005-03-02 16:49:11Z bmeurer $ */
+/* $Id: exo-md5.c 24347 2007-01-10 21:28:37Z benny $ */
 /*-
- * Copyright (c) 2004 os-cillation e.K.
- * Copyright (c) 2004 James M. Cape <jcape@ignore-your.tv>
+ * Copyright (c) 2004-2007 os-cillation e.K.
+ * Copyright (c) 2004      James M. Cape <jcape@ignore-your.tv>
  *
  * Written by Benedikt Meurer <benny@xfce.org>.
  *
@@ -37,6 +37,9 @@
 #endif
 
 #include <exo/exo-md5.h>
+#include <exo/exo-private.h>
+#include <exo/exo-string.h>
+#include <exo/exo-alias.h>
 
 
 
@@ -273,6 +276,11 @@ MD5Final (unsigned char digest[16], MD5_CTX *ctx)
 
 #else
 
+/* RedHat AS, Fedora */
+#ifdef HAVE_MD5GLOBAL_H
+#include <md5global.h>
+#endif
+
 #include <md5.h>
 
 #endif  /* !defined (HAVE_MD5INIT) */
@@ -286,7 +294,7 @@ get_md5 (const gchar *contents,
   MD5_CTX ctx;
 
   MD5Init (&ctx);
-  MD5Update (&ctx, contents, strlen (contents));
+  MD5Update (&ctx, (const guchar *) contents, strlen (contents));
   MD5Final (digest, &ctx);
 }
 
@@ -299,7 +307,7 @@ exo_md5_digest_get_type (void)
 
   if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-      type = g_boxed_type_register_static ("ExoMd5Digest",
+      type = g_boxed_type_register_static (I_("ExoMd5Digest"),
                                            (GBoxedCopyFunc) exo_md5_digest_dup,
                                            (GBoxedFreeFunc) exo_md5_digest_free);
     }
@@ -326,7 +334,7 @@ exo_str_get_md5_digest (const gchar *contents)
 
   g_return_val_if_fail (contents != NULL, NULL);
 
-  digest = g_new (ExoMd5Digest, 1);
+  digest = _exo_slice_new (ExoMd5Digest);
   get_md5 (contents, digest->digest);
 
   return digest;
@@ -379,7 +387,7 @@ exo_md5_str_to_digest (const gchar *str_digest)
   g_return_val_if_fail (str_digest != NULL, NULL);
   g_return_val_if_fail (strlen (str_digest) == 32, NULL);
 
-  digest = g_new (ExoMd5Digest, 1);
+  digest = _exo_slice_new (ExoMd5Digest);
   for (n = 0; n < 16; ++n)
     {
       digest->digest[n] =
@@ -406,17 +414,17 @@ exo_md5_str_to_digest (const gchar *str_digest)
 gchar*
 exo_md5_digest_to_str (const ExoMd5Digest *digest)
 {
-  static gchar hex_digits[] = "0123456789abcdef";
-  guchar      *str_digest;
-  guint        n;
+  static const gchar HEX_DIGITS[] = "0123456789abcdef";
+  guchar            *str_digest;
+  guint              n;
 
   g_return_val_if_fail (digest != NULL, NULL);
 
   str_digest = g_new (guchar, 33);
   for (n = 0; n < 16; n++)
     {
-      str_digest[2 * n]     = hex_digits[digest->digest[n] >> 4];
-      str_digest[2 * n + 1] = hex_digits[digest->digest[n] & 0xf];
+      str_digest[2 * n]     = HEX_DIGITS[digest->digest[n] >> 4];
+      str_digest[2 * n + 1] = HEX_DIGITS[digest->digest[n] & 0xf];
     }
   str_digest[32] = 0;
 
@@ -439,9 +447,20 @@ exo_md5_digest_to_str (const ExoMd5Digest *digest)
 ExoMd5Digest*
 exo_md5_digest_dup (const ExoMd5Digest *digest)
 {
-  g_return_val_if_fail (digest != NULL, NULL);
+  ExoMd5Digest *duplicate;
 
-  return g_memdup (digest, sizeof (*digest));
+  if (G_LIKELY (digest != NULL))
+    {
+      /* take a copy of the digest */
+      duplicate = _exo_slice_new (ExoMd5Digest);
+      memcpy (duplicate, digest, sizeof (*digest));
+      return duplicate;
+    }
+  else
+    {
+      /* duplicating NULL yields NULL */
+      return NULL;
+    }
 }
 
 
@@ -456,7 +475,7 @@ exo_md5_digest_dup (const ExoMd5Digest *digest)
 void
 exo_md5_digest_free (ExoMd5Digest *digest)
 {
-  g_free (digest);
+  _exo_slice_free (ExoMd5Digest, digest);
 }
 
 
@@ -521,3 +540,6 @@ exo_md5_digest_equal (gconstpointer digest1,
 }
 
 
+
+#define __EXO_MD5_C__
+#include <exo/exo-aliasdef.c>
